HoverUssd class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAllActions(
) → Future< List< HoverAction> > - Retrieve a list of available actions.
-
getAllTransactions(
) → Future< List< Transaction> > -
getDownloadActionState(
) → Stream< DonwloadActionState> -
getUssdTransactionState(
) → Stream< TransactionState> - Get the stream of transaction states.
-
hasAccessibilityPermission(
) → Future< bool> -
hasActionsDownloaded(
) → Future< bool> - Check if the app has downloaded actions.
-
hasAllPermissions(
) → Future< bool> - Check if the app has all the necessary permissions.
-
hasContactsPermission(
) → Future< bool> -
hasOverlayPermission(
) → Future< bool> -
hasPhonePermission(
) → Future< bool> -
hasSmsPermission(
) → Future< bool> -
hasWritePermission(
) → Future< bool> -
initialize(
{required String apiKey, String? branding, String? logo, String? notificationLogo}) → Future< void> - Initialize HoverUssd with branding and logo information.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshActions(
) → Future< void> - refresh actions
-
setPermissionsActivity(
{required String activityName}) → Future< void> -
this set custom permissions activity for the app
activityNameis the name of the custom activity to be set ex: 'com.example.example.CustomPermissionsActivity' -
startTransaction(
{required String actionId, Map< String, String> ? extras, String? theme, String? header, String? initialProcessingMessage, int finalMsgDisplayTime = 5000, bool? showUserStepDescriptions}) → Future<void> -
Start a transaction with the provided parameters.
actionIdis the id of the action to be performed.extrasis a map of extra parameters to be sent to the action.themeis the theme of the transaction.headeris the header of the transaction.initialProcessingMessageis the message to be displayed while the transaction is being processed.finalMsgDisplayTimeis the time to display the final message.showUserStepDescriptionsis a flag to show the user step descriptions. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited